@@ -15,23 +15,23 @@
 // You should have received a copy of the GNU General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-#include "hash_sha2_256.h"
+#include "hash_sha2_224.h"
 
 namespace mobius
 {
 namespace crypt
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-// initialization constants (FIPS.180-4 - section 5.3.3)
+// initialization constants (FIPS.180-4 - section 5.3.2)
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static constexpr std::uint32_t H0_VALUE = 0x6a09e667;
-static constexpr std::uint32_t H1_VALUE = 0xbb67ae85;
-static constexpr std::uint32_t H2_VALUE = 0x3c6ef372;
-static constexpr std::uint32_t H3_VALUE = 0xa54ff53a;
-static constexpr std::uint32_t H4_VALUE = 0x510e527f;
-static constexpr std::uint32_t H5_VALUE = 0x9b05688c;
-static constexpr std::uint32_t H6_VALUE = 0x1f83d9ab;
-static constexpr std::uint32_t H7_VALUE = 0x5be0cd19;
+static constexpr std::uint32_t H0_VALUE = 0xc1059ed8;
+static constexpr std::uint32_t H1_VALUE = 0x367cd507;
+static constexpr std::uint32_t H2_VALUE = 0x3070dd17;
+static constexpr std::uint32_t H3_VALUE = 0xf70e5939;
+static constexpr std::uint32_t H4_VALUE = 0xffc00b31;
+static constexpr std::uint32_t H5_VALUE = 0x68581511;
+static constexpr std::uint32_t H6_VALUE = 0x64f98fa7;
+static constexpr std::uint32_t H7_VALUE = 0xbefa4fa4;
 
 //! \brief block size = 64 bytes (512 bits) - FIPS.180-4 - section 1
 static constexpr int BLOCK_SIZE = 64;
@@ -51,7 +51,7 @@ rrot (std::uint32_t v, std::uint32_t n) noexcept
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief default constructor
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-hash_sha2_256::hash_sha2_256 () noexcept
+hash_sha2_224::hash_sha2_224 () noexcept
   : hash_block (BLOCK_SIZE),
     a_ (H0_VALUE),
     b_ (H1_VALUE),
@@ -69,7 +69,7 @@ hash_sha2_256::hash_sha2_256 () noexcept
 //! \brief reset hash value
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
-hash_sha2_256::_reset () noexcept
+hash_sha2_224::_reset () noexcept
 {
   a_ = H0_VALUE;
   b_ = H1_VALUE;
@@ -88,7 +88,7 @@ hash_sha2_256::_reset () noexcept
 //! \see FIPS.180-4 - section 6.2
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
-hash_sha2_256::_update_block (const mobius::bytearray& data) noexcept
+hash_sha2_224::_update_block (const mobius::bytearray& data) noexcept
 {
   std::uint32_t a = a_;
   std::uint32_t b = b_;
@@ -945,9 +945,9 @@ hash_sha2_256::_update_block (const mobius::bytearray& data) noexcept
 // representing the message size in bits (FIPS.180-4 - section 5.1.1)
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 mobius::bytearray
-hash_sha2_256::_evaluate (const mobius::bytearray& data)
+hash_sha2_224::_evaluate (const mobius::bytearray& data)
 {
-  hash_sha2_256 tmp (*this);
+  hash_sha2_224 tmp (*this);
 
   // represent message size in bits as a bytearray
   std::uint64_t bits = ((size_ + data.size ()) << 3);
@@ -1019,13 +1019,9 @@ hash_sha2_256::_evaluate (const mobius::bytearray& data)
     std::uint8_t (g_ >> 24),
     std::uint8_t (g_ >> 16),
     std::uint8_t (g_ >> 8),
-    std::uint8_t (g_),
-    std::uint8_t (h_ >> 24),
-    std::uint8_t (h_ >> 16),
-    std::uint8_t (h_ >> 8),
-    std::uint8_t (h_),
+    std::uint8_t (g_)
   };
-  
+
   *this = tmp;
   return digest;
 }
